@@ -62,8 +62,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct PaginatorWidget(ObjectSubclass<imp::PaginatorWidget>)
-        @extends gtk::Widget, gtk::Box,
-        @implements gtk::Buildable;
+        @extends gtk::Widget, adw::Bin,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 #[gtk::template_callbacks]
