@@ -81,7 +81,9 @@ mod imp {
 glib::wrapper! {
     pub struct Window(ObjectSubclass<imp::Window>)
         @extends gtk::Widget, gtk::Window, gtk::ApplicationWindow, adw::ApplicationWindow,
-        @implements gio::ActionMap, gio::ActionGroup;
+        @implements gio::ActionMap, gio::ActionGroup, gtk::Accessible,
+                    gtk::Buildable, gtk::ConstraintTarget, gtk::Native, gtk::Root,
+                    gtk::ShortcutManager;
 }
 
 impl Window {
